@@ -20,7 +20,7 @@ import os.path
 import gtweak
 from gtweak.utils import walk_directories, make_combo_list_with_default
 from gtweak.tweakmodel import TWEAK_GROUP_WINDOWS, TWEAK_GROUP_THEME
-from gtweak.widgets import GSettingsComboTweak, GSettingsComboEnumTweak
+from gtweak.widgets import GSettingsComboTweak, GSettingsComboEnumTweak, GSettingsSwitchTweak
 
 class WindowThemeSwitcher(GSettingsComboTweak):
     def __init__(self, **options):
@@ -43,4 +43,9 @@ TWEAKS = (
     GSettingsComboEnumTweak("org.gnome.desktop.wm.preferences", "action-middle-click-titlebar", group_name=TWEAK_GROUP_WINDOWS),
     GSettingsComboEnumTweak("org.gnome.desktop.wm.preferences", "action-right-click-titlebar", group_name=TWEAK_GROUP_WINDOWS),
     GSettingsComboEnumTweak("org.gnome.desktop.wm.preferences", "focus-mode", group_name=TWEAK_GROUP_WINDOWS),
+    GSettingsComboTweak("org.gnome.desktop.wm.preferences",
+                        "mouse-button-modifier",
+                        [("disabled", _("Disabled")), ("<Alt>", "Alt"), ("<Super>", "Super")],
+                        group_name=TWEAK_GROUP_WINDOWS),
+    GSettingsSwitchTweak("org.gnome.desktop.wm.preferences", "resize-with-right-button", group_name=TWEAK_GROUP_WINDOWS),
 )
